# **Molecular Visualization with Chimera**
\pagenumbering{gobble}

In this session, you will utilize USCF Chimera to view and interrogate
two biomolecular structures. This program is freely available for
Microsoft Windows, Mac OSX, Linux, and UNIX-based computer operating
systems such as IRIX. From home (or your home lab), you may download the
Chimera structure viewer from the UCSF
website: [http://www.cgl.ucsf.edu/chimera/download.html](http://www.cgl.ucsf.edu/chimera/download.html)

Chimera menu commands will be designated as: ***Button -\> button -\>
button*** .

Chimera command line commands are indicated after: **command\>**

In addition to this handout, you should receive a copy of [The Chimera Quick Reference Guide](http://www.cgl.ucsf.edu/chimera/docs/UsersGuide/quickref.pdf) (UCSF).

**Section A: Investigating Hemoglobin**
=======================================

1\. View the PDB file for human Hemoglobin (1GZX)
------------------------------------------------------

In a terminal window, type **chimera**. This is a newer, larger program
than e.g. RasMol, and will take much longer to start running. You can
drag the bottom right corner of the Chimera window to expand the window
size to something comfortable for you.

Now, automatically fetch the structure of hemoglobin from the Protein
Data Bank.

1.  ***File -\> Fetch by ID -\> Type 1GZX -\> Fetch***
2.  Rotate the structure with the left mouse button (button 1)
3.  Translate (move) the structure with the middle mouse button (button 2)
4.  Zoom in on the structure with the right mouse (button 3)

Here, we start with a PDB code we already know. Usually, we don't know
that beforehand, so you would go to rcsb.org and search for your protein
of interest. If you haven't done this before, go there and examine the
"Molecule of the Month" entry for hemoglobin.

2\. Highlight and color individual protein chains
------------------------------------------------------

***Tools -\> Depiction -\> Rainbow -\> Chain***

3\. Color the heme cofactors using the Chimera command line
----------------------------------------------------------------

(if the command line is not visible at the bottom of the window,
choose ***Favorites -\> Command Line***)

1.  **command\> color purple \#0:HEM**
2.  **command\> color orange \#0:HEM@FE**

You'll want to learn the syntax used for specifying selections:

**\#[model number]:[residue name or number]@[atom name]**

Further details can be found under atom specification on this page (it's
not a bad idea to keep this page open while working in Chimera):

[http://www.cgl.ucsf.edu/chimera/docs/UsersGuide/framecore.html](http://www.cgl.ucsf.edu/chimera/docs/UsersGuide/framecore.html)

4\. Display heme atoms (and NOT the Fe atoms) as type ‘ball & stick’
-------------------------------------------------------------------------

1.  ***Select -\> Residue-\> HEM***
2.  **Shift+Ctrl+click** on the Fe atoms to deselect just the iron atoms. \
    (A Ctrl+click on the background will deselect everything.)
3.  ***Actions -\> Atoms/Bonds -\> ball and stick***

5\. Focus on the heme binding site of hemoglobin Chain B
-------------------------------------------------------------

1.  **Ctrl+click** on any atom of the heme to select it (Hover over
    different hemes to determine which is chain B)
2.  **Shift+Ctrl+up-arrow** to expand selection to include entire heme
3.  ***Actions-\> Focus***

6\. Show ONLY the heme binding site for hemoglobin Chain B
---------------------------------------------------------------

1.  ***Select -\> Zone -\> \<5.0 angstroms from currently selected
    atoms***
2.  Click button for ‘***Select all atoms/bonds of any residue in
    selection zone***’
3.  ***Actions -\> Atoms/Bonds -\> show***
4.  ***Select -\> Invert (all models)***
5.  ***Actions -\> Atoms/Bonds -\> hide***
6.  ***Actions -\> Ribbon -\> hide***

7\. Color the heme and binding site sidechains according to atom type
--------------------------------------------------------------------------

1.  ***Invert the selection again (or re-select the heme and the zone of
    nearby residues).***
2.  ***Actions -\> Color -\> by heteroatom***

You should now see Nitrogen atoms in blue, Oxygen atoms in red, and
Sulfur atoms in yellow.

8\. Render the coordinated His residue (H235) as ‘ball & stick’
--------------------------------------------------------------------

1.  **command\> select \#0:235.B**
2.  ***Actions -\> Atoms/Bonds -\> ball & stick***

9\. Color only the H235 side chain
---------------------------------------

1.  ***Actions -\> Color -\> all options***
2.  Select "***Coloring applies to: atoms/bonds***"
3.  Click the "***red***" button

10\. Color heme binding site side chains yellow (except H235)
------------------------------------------------------------------

1.  ***Select -\> Structure -\> sidechain/base -\> without CA/C1'***
2.  **command\> \~select \#0:235.B** \
    (That command begins with a "tilde" character meaning de-select.)
3.  ***Action -\> Color -\> yellow***
4.  ***Select -\> Clear selection***

11\. Render all solvent molecules as type “ball”
-----------------------------------------------------

1.  ***Select -\> Structure -\> solvent***
2.  ***Actions -\> Atoms/Bonds -\> ball & stick***
3.  ***Actions -\> Color -\> by element***

12\. Save the session to resume later
------------------------------------------

1.  ***File -\> Save Session As -\> hg\_session.py***
2.  ***File -\> Close Session***

**Section B: Viewing bovine rhodopsin (1L9H)** 
==============================================

Exploration of the high resolution X-ray structure for bovine rhodopsin
should provide an opportunity for us to combine many of the
visualization techniques covered up to this point – plus an opportunity
to see a few more. Here, the ligand, 11-cis-retinal (RET), is a
covalently bound inverse agonist that locks the protein into an inactive
(dark state) conformation. Our annotation of this structure will
illustrate in atomic detail the chemical and physical composition of the
ligand-binding site of this G-protein coupled receptor, an integral
membrane protein that has seven membrane-spanning segments.

1\. Basic annotation of the pre-edited PDB file
----------------------------------------------------

A pre-edited version of the rhodopsin PDB file exists locally to load
into Chimera.

Display the protein backbone trace.

1.  ***File -\> Open -\> Filename:
    /home/momokurs/rosetta\_workshop/tutorials/day02/sample\_files/rho.pdb***
2.  ***Actions -\> Atoms/Bonds -\> backbone only*** ***-\> chain
    trace***

Display the protein secondary structure.

1.  ***Select -\> Structure -\> secondary structure-\> helix***
2.  ***Actions -\> Ribbon -\> show; Actions -\> Ribbon -\> edged***
3.  ***Actions -\> Color -\> all options; ribbons; green***
4.  ***Select -\> Structure -\> secondary structure -\> strand***
5.  ***Actions -\> Ribbon -\> show; Actions -\> Ribbon -\> edged***
6.  ***Actions -\> Color -\> orange***

Display and color the conserved disulfide bond in rhodopsin.

1.  **command\> select \#0:110.A,187.A**
2.  ***Actions -\> Atoms/Bonds -\> show***
3.  ***Actions -\> Focus***
4.  ***Actions -\> Atoms/Bonds -\> stick***
5.  ***Actions -\> Color -\> all options; atoms/bonds; by
    element***

2\. Adjust your viewing parameters to reduce the data displayed
--------------------------------------------------------------------

Position the camera looking into the helix bundle from just above the
beta strands.

Highlight the ligand, 11-cis retinal (RET)

1.  ***Select -\> Residue -\> RET***
2.  ***Actions -\> Atoms/Bonds -\> stick***
3.  ***Actions -\> Color -\> all options; atoms/bonds; medium blue***

Display any water molecules bound near the ligand.

1.  ***Select -\> Structure -\> solvent***
2.  ***Actions -\> Atoms/Bonds -\> ball & stick***
3.  ***Actions -\> Color -\> red***

Try adjusting the clipping planes to hide some detail and focus on the
ligand binding site.

1.  ***Tools -\> Viewing Controls -\> Side View*** \<or\> ***Favorites -\> Side View***

2.  Drag front (left) and back (right)
    yellow clipping planes to adjust the molecular detail in your view.

Chimera starts in mono viewing mode by default. You can enable stereo
viewing mode.

1.  ***Tools -\> Viewing Controls -\> Camera -\> camera mode: cross-eye*** or ***wall-eye stereo***
2.  You can continue in stereo or mono.

3\. Highlight the fit into the ligand binding site of the rhodopsin protein.
---------------------------------------------------------------------------------

Focus on the 11-cis retinal ligand-binding site.

1.  ***Select -\> Residue -\> RET***
2.  ***Actions -\> Focus***

Show amino acid side chains within 5.0 Angstrom of the ligand.

1.  ***Select -\> Zone -\> *****\<= 5.0 angstrom from currently selected
    atoms**
2.  Click '***Select all atoms/bonds of any residue in selection
    zone'***
3.  ***Actions -\> Atoms/Bonds -\> show***
4.  ***Actions -\> Atoms/Bonds -\> stick***
5.  **command\> ****\~****select \#0:RET.A** \
    (with a tilde to negate the select command)
6.  ***Actions -\> Color -\> all options; atoms/bonds; by element***

Render a semi-transparent surface for the ligand.

1.  ***Select -\> Residue -\> RET***
2.  ***Actions -\> Surface -\> show***
3.  ***Actions -\> Color -\> all options, surfaces; gray***
5.  ***Actions -\> Surface -\> transparency -\> 50%***

Save the image in a file

1.  ***Actions -\> Color -\> all options; background; white***
2.  ***File -\> Save Image -\> adjust Image width to 1024 pixels***
3.  ***File name -\> rhodopsin.png***
4.  ***Save***

Two additional points. You can see that the repetive use of menus gets
tiresome. As you use chimera more, you will get faster if you learn the
commands listed on the quick reference sheet, and type them into the
commandline.

Secondly, writing and modifying scripts can be very useful for creating
figures. The script can also be customized by editing it as a text file.
This is a very powerful method for accelerating your visualization work,
so an example script has been provided here for you to experiment with
and customize.

**\~/rosetta\_workshop/tutorials/day02/sample\_files/startup.cmd**

Copy it to your home directory. Load a new structure and run the script.
(Run scripts by opening them with ***File -\> Open***)
View the script in a text editor. Try making changes to suit your protein of
interest.

**Section C: Create a clear visualization of a DNA-ligand complex (1L9H)**
==========================================================================

Duplicate the DNA-duocarmycin representation you already made with
pymol. If you can, try to do it without reading the steps below. Then
read through them to find any things you might have missed.

1.   ***File -\> Fetch by ID -\> 1DSM***
2.   **command\> select**
3.   **command\> \~select \#0.1** \
    (That line begins with a "tilde" character)
4.   **command\> delete sel**
5.   ***Tools -\> Depiction -\> Rainbow (by chain, apply)***
6.   ***Actions -\> Atoms/Bonds -\> nucleotide objects -\> off***
7.   select (**Ctrl-click**) the covalent bond between Adenosine 5 and
    the DSA
8.   ***Actions -\> Atoms/Bonds -\> delete ***(so that the surfacing
    command can be limited)
9.   ***Select -\> Residue -\> DSA***
10.  ***Actions -\> Color -\> by heteroatom***
11.  ***Actions -\> Surface -\> show***
12.  ***Actions -\> Surface -\> transparency -\> 80%***
13.  ***Favorites -\> Model Panel -\> ***double-click on MSMS surface to
    see attributes, set vertex density=10
14.  ***Select -\> Chemistry -\> Element -\> H***
15.  ***Actions -\> Atoms/Bonds -\> hide***
16.  ***Tools -\> Depictions -\> Nucleotides ***(start with defaults.
    Vary the options according to taste.)
17. Save a **.png** image in your working directory. Save the session for later.

