#**Introduction to Molecular Visualization with RasMol**
\pagenumbering{gobble}

In this session, you will be introduced to some interactive graphics
techniques that are commonly used to view and interrogate biomolecular
structures. While there are many computer programs that are available
for this purpose, for these exercises, we will utilize RasMol. This
program is freely available for Microsoft Windows, Mac OSX, Linux, and
UNIX-based computer operating systems.

Several example protein structures will be presented to illustrate
common techniques for quickly obtaining useful information from
structures of large biomolecules. Although you will be stepping through
the operational details of visualization tasks, the session should give
you a general idea of the conceptual aspects of visually processing
biomolecular structure data.

Today's tutorial can be completed on Linux or Silicon Graphics Irix
workstations. The basic unix commands will work identically on either of
these.

At the conclusion of today’s session, you should be able to quickly
render a structure of interest (using various techniques in RasMol) and
quickly extract scientifically useful information from a given structure
data file.

RasMol menu commands will be designated as ***Button -\> button -\>
button*** .

RasMol command line commands are indicated after the
prompt- **RasMol\>** To get the rasmol command prompt, go to ***View -\>command prompt*** or press the F7 key. 

From home (or your home lab), you may download the RasMol structure
viewer from the RasMol website: \
[http://www.umass.edu/microbio/rasmol/index2.htm](http://www.umass.edu/microbio/rasmol/index2.htm)

In addition to this handout, you should receive a copy of the RasMol
Quick Reference
sheet [rasMolQR.pdf](https://structbio.vanderbilt.edu/twiki/pub/CSBTutorials/MolVizRasMol/rasMolQR.pdf) .

Viewing the Potassium Channel 
=============================

First, you should make a working directory for today. Name it with e.g.
today's date. Then copy the pdb file to your directory using this
command at the unix prompt (using the terminal):

**cp /home/momokurs/rosetta\_workshop/tutorials/day02/sample\_files/1BL8.pdb .**

This file contains the structure of the KcsA potassium channel
from *streptomyces Lividans*, determined at 3.2 Angstrom resolution in
the MacKinnon lab in 1998. This channel is most well-known for its role
in neuron function, but this type of channel is also fundamentally
important for cellular biology.

1\. Load and view the coordinate file 1BL8.pdb
------------------------------------------

At the unix prompt (in the terminal), type **rasmol**. This starts the
program with a new graphical display window, but note that the program
also continues to display information and accept commands in the
terminal window. This gives you two methods to interact with the
program: graphical and text. You will make use of both.

Load the PDB file containing the structure:

1.  ***File -\> Open -\>*** [now the terminal window asks for your
    input]
2.  type: **1BL8.pdb** in the terminal
3.  Rotate the structure with the left mouse button (button 1)
4.  Translate (move) the structure with the middle mouse button (button
    2)
5.  Zoom in on the structure by holding down the shift key and the left
    mouse button, and moving up and down (shift-drag)

Note that the structure file could have been loaded by typing:

    load ~/rosetta\_workshop/tutorials/day02/sample_files/1BL8.pdb

at the text prompt. There is often more than one way to do it.

RasMol has the ability to display molecules in stereo, but it requires
the user to learn to see in "cross-eyed" mode. Those who make the effort
are rewarded with a greatly enriched view of the structure.

1.  Stretch the window to twice its width.
2.  ***Options-\> Stereo***
3.  Cross your eyes until the middle 2 images converge. You will have to
    learn to focus with your eyes crossed.

Continuing in stereo mode is optional. It requires some work, but it is
a valuable skill to learn. Newer computer software, running with special
hardware, provides stereo via fancy goggles. But on most computers, and
also in print, you will come across many structural images that can be
viewed in 3D using cross-eyed stereo. The related "divergent stereo", in
which you stare past the images, is also common. If you get tired of
stereo mode, you can turn it off at any time by toggling the menu item
(twice, because it switches between mono, cross-eyed, and divergent
stereo).

2\. Examine the text of the pdb file 
------------------------------------------

It is useful to look at the contents of the structure file while viewing
the structure. Use a text editor like gedit or vim (on an SGI, good ones
are **nedit** and **jot**).

1.  Open the file 1BL8.pdb and read the first 20-30 lines for an
    overview. (**nedit 1BL8.pdb** from a terminal window)
2.  Skip over the REMARKs containing crystallographic detail. Scroll
    down to the SEQRES entries, which give the amino acid sequence of
    each chain (the chain is specified in the 3rd column).
3.  Scroll down to the HELIX entries, which define the residues involved
    in secondary structures. Identify the starting and ending residue of
    each helix.
4.  Last, scroll down to the ATOM records, which specify the 3D
    coordinates of each atom in the structure. Note that each atom has a
    unique number, an atom type (like CA for alpha carbon), the residue
    type and chain identifiers, and the residue number, in columns 2-6.

3\. Investigate the structure using different display modes
-------------------------------------------------------

1.  ***Display -\> Backbone*** only traces the alpha carbons for a
    simplified overview (Particularly useful for stereo)
2.  ***Display -\> Strands*** even more abstract, emphasizing secondary
    structure
3.  ***Display -\> Sticks/Ball and Stick*** high detail; good when
    zoomed in
4.  ***Display -\> Cartoon*** one of the most popular displays for
    proteins
5.  ***Colours -\> Structure*** nicely highlights secondary structure
    elements for a good structural understanding of the protein
6.  ***Colours -\> Chain*** provides insight into the quaternary
    organization
7.  ***Display -\> Spacefill*** shows a good approximation of the volume
    and surface
8.  ***Colours -\> Temperature*** maps the B-factor of each residue, a
    measure of its motion or flexibility, to a color scale. Cooler
    colors like blue indicate less mobile sidechains. If you rotate the
    molecule, you may notice some bulky hydrophobic side chains (roughly
    in two planes) that are surprisingly mobile (highlighted with yellow
    and orange) and surface-exposed. Does this help you envision the
    embedding of the channel in the membrane?

4\. Display and examine important residues and atoms
-------------------------------------------------

1.  ***Display -\> Cartoons, Colours -\> Chain*** to simplify the
    display
2.  **RasMol\> select hetero** this will select non-protein atoms,
    including cofactors, ions, and any water molecules included in the
    structure
3.  ***Display -\> Spacefill*** shows four atoms caught in the pore of
    the channel
4.  ***Colors -\> CPK*** helps distinguish the O of water from the K+
    ions (note that hydrogens are seldom seen in X-ray structures)
5.  **RasMol\> select not hetero** this inverts the selection – only
    protein
6.  ***Display -\> Spacefill*** this shows how tightly the ions fill the
    pore
7.  ***Display -\> Sticks*** shows the coordination around the ions, but
    is rather busy
8.  ***Display -\> Cartoons*** go back to schematic view
9.  **RasMol\> select within (7.0, hetero) and not hetero** this will
    select everything within a 7 Angstrom radius of the heteroatoms
10. ***Display -\> Sticks*** shows details of only the nearby residues
11. Examine the ion coordination in the pore. This is the structure that
    revealed the mechanism of ion selectivity in the potassium channel.
    This filter permits only one Na+ atom for every 10,000 K+ ions.

5\.Make a nice looking image
--------------------------

1.  Zoom in closely on the ions. To keep the foreground helices from
    obstructing the view, activate the clipping plane: ctrl-drag down.
    That is, hold down the ctrl key and the left mouse button, and drag
    the mouse down until the foreground objects disappear.
2.  To keep the pore in the center while rotating, do ***Settings -\>
    Pick centre*** then click on the water Oxygen. Immediately reset it
    to ***Settings -\> Pick ident.***
3.  Rotate the model and examine the ion coordination. Note how many of
    the oxygens used are from the peptide backbone. Find a sidechain
    oxygen that's involved by clicking on the atoms to identify them.
    Look for output similar to: \
    **Atom: OG1 1790 Group: THR 75 Chain: C**
4.  **RasMol\> select within (7.0, hetero) and thr** to affect only the
    four Threonines.
5.  **RasMol\> color orange** to give them a distinct color
6.  **RasMol\> background white** for nicer printing
7.  **RasMol\> write ps output.ps** to generate a postscript file

Further exploration 
-------------------

If you have additional time, make a similar image highlighting the
important residues in the heme coordinating site of cytochrome B5, using
the pdb file 1CYO.

When doing substantial work in Rasmol, it would be reasonable to open a
browser window to the user manual:

[http://www.umass.edu/microbio/rasmol/distrib/rasman.htm](http://www.umass.edu/microbio/rasmol/distrib/rasman.htm)

