Display of the charged surface of a protein 
===========================================
\pagenumbering{gobble}

Purpose: Learn multiple ways to display the surface charge on a protein
structure. Pay attention to the advantages and disadvantages of the
different methods.

1\. What this is not:
-------------------

Many molecular visualization tools can easily generate a surface
representation of your molecule, typically a “solvent-excluded volume”.
They can frequently color that surface according to the charged residues
under it, usually red for negative and blue for positive.

1.  Pymol - Use the small buttons in the upper right-hand corner,
    -   **all-\>show-\>as-\>surface**
    -   With one click, you have the charges represented as you expect,
        plus hydrophobic surface represented in green.
    -   To make a particularly pretty surface display,
        look [here.](http://pymolwiki.org/index.php/Surface)

2.  Chimera 
    - **Actions -\> Surface -\> Show**
    - **Actions -\> Color -\> by heteroatom**
        This is a very simple representation just showing the location of nitrogen and oxygen atoms

*Important Note: These are over-simplified views of what residues are
under the surface. This does not represent the actual charge field in
any accurate way. For that, you have to calculate the electrostatics
properly. See below.*

2\. Grasp 
--------

This is one of the canonical methods of generating an accurate
electrostatic potential for a macromolecule. (along with Delphi, MEAD,
Zap, etc.) The user interface takes some work getting used
to. **NOTE** It is available **only** on SGI computers, and so
we will not be using it for today's workshop. It is mentioned here only
for illustration. To learn more about it, visit the Honig lab webpage:
http://wiki.c2b2.columbia.edu/honiglab\_public/index.php/Software:GRASP

[See also Sybyl, part of the Tripos package, for an integrated
commercial tool.]

3\. Pymol 
----------

There are two ways to do it in Pymol. You can try both or pick one:

1.  **(molecule)-\>A(ctions)-\>generate-\>vacuum
    electrostatics-\>protein contact potential (local)** \
    This has a disclaimer about poor accuracy... but it's a quick first
    approximation.
2.  The more thorough way to do it is to use the menu item:\
    **Plugin-\>APBS tools (Adpative Poisson-Boltzmann Solver)** \
    Click "Use PyMol generated PQR and PyMol generated Hydrogens and termini", then "Set grid", then "Run APBS". Wait for the run to finish.
    (“ObjectMap: Map Read.”) Note that there may be errors with more complicated structures. Try again with a simpler structure (like 1UBQ).

3.  Finally, click on the Visualization tool, update, and click
    on **Show Molecular Surface**. You may want to select “Solvent
    accessible surface” and “color by potential on sol. acc. surf.” and
    increase the color ramp range by adjusting the high and low
    setpoints.

APBS does a more rigorous calculation using correct dielectrics for the
protein and solvent, etc. However, it can run into some difficulties if
there are e.g. non-standard or missing residues in your pdb file. You
may have to edit your pdbfile to get it to work smoothly. If that's not
feasible, you can go back to GRASP, which complains less about defective
structures, or:

4\. APBS standalone + Chimera
----------------------------

In cases where the PyMOL plugin doesn't work well, you may want to have
more control- for instance, the ability to manually edit the
intermediate files. The following procedure will allow you to do that:

1.  Generate input files for APBS by visiting the PDB2PQR server:

    1.  Go to this website:
        [http://nbcr-222.ucsd.edu/pdb2pqr\_1.9.0/](http://nbcr-222.ucsd.edu/pdb2pqr_1.8/)
    2.  Upload your pdb file, use whatever forcefield you want (default
        should be ok), internal naming scheme, check Ensure that new
        atoms are not rebuilt too close to existing atoms, check
        Optimize the hydrogen bonding network, check Create an APBS
        input file.
    3.  Click submit. After a few seconds or minutes it'll give you the
        .pqr and apbs .in files. You should inspect these with a text
        editor (not a word processor) and customize them if necessary.
    4.  Download these into the same directory and then
        run `apbs file.in`
    5.  In case you don't have the apbs software available, example
        files have been provided. Look in the sample\_files/ directory
        for files named 1hne.\*

2.  Display in Chimera

    1.  After you have the pot.dx file just load your pdb into chimera,
        make a surface
    2.  then go into **tools -\> surface/binding analysis -\>
        electrostatic surface coloring** , load the .dx file and then
        click color.
        1.  The usual way to display is to use three colors red, white,
            blue with -10, 0, 10 or -15, 0, 15 kT/q


